"""
kvenv - Run commands with environment variables resolved from Azure Key Vault.
"""

from __future__ import annotations

__version__ = "0.1.0"

from .keyvault import (
    AzureCliNotFoundError,
    InvalidSecretNameError,
    InvalidVaultNameError,
    KeyVaultAccessError,
    KeyVaultError,
    fetch_secret,
    validate_secret_name,
    validate_vault_name,
)
from .parser import EnvEntry, EnvParseError, parse_env_file

__all__ = [
    "__version__",
    # Parser
    "EnvEntry",
    "EnvParseError",
    "parse_env_file",
    # Key Vault
    "KeyVaultError",
    "AzureCliNotFoundError",
    "KeyVaultAccessError",
    "InvalidVaultNameError",
    "InvalidSecretNameError",
    "fetch_secret",
    "validate_vault_name",
    "validate_secret_name",
]
